@@ -1,16 +1,16 @@
 /*
-    Copyright 20011 Julian Helfferich <julian.helfferich@gmail.com> 
-  
+    Copyright 20011 Julian Helfferich <julian.helfferich@gmail.com>
+
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 2 of the License, or
     (at your option) any later version.
-   
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-   
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
@@ -27,14 +27,14 @@ class LevelLoader : public QObject
 {
     Q_OBJECT
 public:
-    LevelLoader( QObject *parent = 0 );
+    LevelLoader(QObject *parent = 0);
     ~LevelLoader();
-    
+
     int level() const;
-    void setLevel( int level );
+    void setLevel(int level);
     QString levelset() const;
-    void setLevelset( const QString& levelname );
-  
+    void setLevelset(const QString &levelname);
+
     void loadLevel();
 
 signals:
@@ -42,14 +42,14 @@ signals:
     void newGift(QString giftType, int times, QString position);
 
 private:
-    void loadLine( QDomElement lineNode );
-    void loadGift( QDomElement giftNode );
-    
+    void loadLine(QDomElement lineNode);
+    void loadGift(QDomElement giftNode);
+
     void loadOldStyleLevel();
-    
+
     QDomDocument *m_levelset;
     bool m_oldstyle;
-    
+
     int m_lineNumber;
     QString m_levelname;
     int m_level;
@@ -59,28 +59,28 @@ private:
 // Can be removed, when KConfig levelsets are no longer supported
 
 const QString GIFT_TYPES[] = {
-    "Gift100Points",
-    "Gift200Points",
-    "Gift500Points",
-    "Gift1000Points",
-    "GiftAddLife",
-    
-    "GiftLoseLife", 
-    "GiftNextLevel",
-    "GiftSplitBall",
-    "GiftAddBall",
-    "GiftDecreaseSpeed",
-    
-    "GiftIncreaseSpeed",
-    "GiftUnstoppableBall",
-    "GiftBurningBall",
-    "GiftMagicWand",
-    "GiftMagicEye",
-    
-    "GiftEnlargeBar",
-    "GiftShrinkBar",
-    "GiftStickyBar",
-    "GiftMoreExplosion"
+    QLatin1Literal("Gift100Points"),
+    QLatin1Literal("Gift200Points"),
+    QLatin1Literal("Gift500Points"),
+    QLatin1Literal("Gift1000Points"),
+    QLatin1Literal("GiftAddLife"),
+
+    QLatin1Literal("GiftLoseLife"),
+    QLatin1Literal("GiftNextLevel"),
+    QLatin1Literal("GiftSplitBall"),
+    QLatin1Literal("GiftAddBall"),
+    QLatin1Literal("GiftDecreaseSpeed"),
+
+    QLatin1Literal("GiftIncreaseSpeed"),
+    QLatin1Literal("GiftUnstoppableBall"),
+    QLatin1Literal("GiftBurningBall"),
+    QLatin1Literal("GiftMagicWand"),
+    QLatin1Literal("GiftMagicEye"),
+
+    QLatin1Literal("GiftEnlargeBar"),
+    QLatin1Literal("GiftShrinkBar"),
+    QLatin1Literal("GiftStickyBar"),
+    QLatin1Literal("GiftMoreExplosion")
 };
 
 // IMPORTANT: keep in sync with the above
